==> elgg-1.11.0.zip: elgg-1.11.0/mod/messageboard/languages/es.php <==
<?php

return array(

	/**
	 * Menu items and titles
	 */

	'messageboard:board' => "Tabl&oacute;n de mensajes",
	'messageboard:messageboard' => "tabl&oacute;n de mensajes",
	'messageboard:viewall' => "Ver todo",
	'messageboard:postit' => "Post",
	'messageboard:history:title' => "Historial",
	'messageboard:none' => "No hay nada en este tabl&oacute;n de mensajes",
	'messageboard:num_display' => "N&uacute;mero de mensajes a mostrar",
	'messageboard:desc' => "este es un tabl&oacute;n de mensajes en el que puedes poner contenido y otros usuarios pueden comentar.",

	'messageboard:user' => "Tabl&oacute;n de mensajes de %s",

	'messageboard:replyon' => 'responder en',
	'messageboard:history' => "historial",

	'messageboard:owner' => 'Tabl&oacute;n de mensajes de %s',
	'messageboard:owner_history' => 'Posts de %s en el tabl&oacute;n de mensajes %s',

	/**
	 * Message board widget river
	 */
	'river:messageboard:user:default' => "%s ha publicado en el tabl&oacute;n de mensajes %s",

	/**
	 * Status messages
	 */

	'messageboard:posted' => "Se ha publicado en tu tabl&oacute;n de mensajes exitosamente.",
	'messageboard:deleted' => "Se ha borrado el mensaje.",

	/**
	 * Email messages
	 */

	'messageboard:email:subject' => 'Tienes nuevos comentarios en el tabl&oacute;n de mensajes',
	'messageboard:email:body' => "Tienes comentarios en tu tabl&oacute;n de mensajes %s. Leelo:

%s

Para ver los comentarios en tu tabl&oacute;n de mensajes, haz click a continuaci&oacute;n:

	%s

Para ver el perfil de %s, haz click a continuaci&oacute;n:

	%s

No se puede responder a este email.",

	/**
	 * Error messages
	 */

	'messageboard:blank' => "Es necesario poner algo en el campo del mensaje antes de guardar.",
	'messageboard:notfound' => "No se pudo encontrar el elemento especificado.",
	'messageboard:notdeleted' => "No se pudo borrar este mensaje.",
	'messageboard:somethingwentwrong' => "Algo sali&oacute; mal al guardar el mensaje. Aseg&uacute;rate de haberlo escrito.",

	'messageboard:failure' => "Ocurri&oacute; un error desconocido al guardar el mensaje. Intenta de nuevo.",

);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/messageboard/languages/es.php <==
<?php

return array(

	/**
	 * Menu items and titles
	 */

	'messageboard:board' => "Tabl&oacute;n de mensajes",
	'messageboard:messageboard' => "tabl&oacute;n de mensajes",
	'messageboard:none' => "No hay nada en este tabl&oacute;n de mensajes",
	'messageboard:num_display' => "N&uacute;mero de mensajes a mostrar",
	'messageboard:user' => "Tabl&oacute;n de mensajes de %s",
	'messageboard:owner' => 'Tabl&oacute;n de mensajes de %s',
	'messageboard:owner_history' => 'Posts de %s en el tabl&oacute;n de mensajes %s',

	/**
	 * Message board widget river
	 */
	'river:user:messageboard' => "%s posted on %s's message board",

	/**
	 * Status messages
	 */

	'messageboard:posted' => "Se ha publicado en tu tabl&oacute;n de mensajes exitosamente.",
	'messageboard:deleted' => "Se ha borrado el mensaje.",

	/**
	 * Email messages
	 */

	'messageboard:email:subject' => 'Tienes nuevos comentarios en el tabl&oacute;n de mensajes',
	'messageboard:email:body' => "You have a new message board comment from %s.

It reads:

%s

To view your message board comments, click here:
%s

To view %s's profile, click here:
%s",

	/**
	 * Error messages
	 */

	'messageboard:blank' => "Es necesario poner algo en el campo del mensaje antes de guardar.",
	'messageboard:notdeleted' => "No se pudo borrar este mensaje.",

	'messageboard:failure' => "Ocurri&oacute; un error desconocido al guardar el mensaje. Intenta de nuevo.",

	'widgets:messageboard:name' => "Message board",
	'widgets:messageboard:description' => "This is a message board that you can put on your profile where other users can comment.",
);
